package com.landray.kmss.sys.attachment.jg;

import java.io.File;
import com.landray.kmss.util.IDGenerator;
import com.landray.kmss.util.FileUtil;
import DBstep.iMsgServer2000;
import com.landray.kmss.common.actions.RequestContext;
import org.slf4j.LoggerFactory;
import org.slf4j.Logger;

public class SysAttJGSaveFileFunctionPatch extends SysAttJGSaveFileFunction
{
    private static final Logger logger;
    
    static {
        logger = LoggerFactory.getLogger(SysAttJGSaveFileFunctionPatch.class);
    }
    
    @Override
    public void execute(final RequestContext request, final iMsgServer2000 MsgObj) throws Exception {
        final String fileType = MsgObj.GetMsgByName("FILETYPE");
        Boolean canSave = false;
        if (".doc".endsWith(fileType.toLowerCase()) || ".docx".endsWith(fileType.toLowerCase()) || ".xlsx".endsWith(fileType.toLowerCase()) || ".wps".endsWith(fileType.toLowerCase()) || ".et".endsWith(fileType.toLowerCase())) {
            String fdSystemTempPath = FileUtil.getSystemTempPath();
            if (!fdSystemTempPath.endsWith("/")) {
                fdSystemTempPath = String.valueOf(fdSystemTempPath) + "/";
            }
            String tmpId = IDGenerator.generateID();
            String filePath;
            File tmpFile;
            for (filePath = String.valueOf(fdSystemTempPath) + tmpId + "_tmp" + fileType, tmpFile = new File(filePath); tmpFile.exists(); tmpFile = new File(filePath)) {
                tmpId = IDGenerator.generateID();
                filePath = String.valueOf(fdSystemTempPath) + tmpId + "_tmp" + fileType;
            }
            final File tmpPfile = tmpFile.getParentFile();
            if (!tmpPfile.exists()) {
                tmpPfile.mkdirs();
            }
            tmpFile.createNewFile();
            if (MsgObj.MsgFileSave(filePath)) {
                final long startTime = System.currentTimeMillis();
                final String ret = MsgObj.CheckFileValid(filePath);
                final long endTime = System.currentTimeMillis();
                SysAttJGSaveFileFunctionPatch.logger.info("poi程序运行时间： " + (endTime - startTime) + "ms");
                if ("ok".equals(ret)) {
                    SysAttJGSaveFileFunctionPatch.logger.info("POI检验文档成功!");
                    canSave = true;
                }
                else if ("NoSheetPages".equals(ret)) {
                    SysAttJGSaveFileFunctionPatch.logger.info("Sheet页为0!");
                }
                else if ("FileEncryption".equals(ret)) {
                    SysAttJGSaveFileFunctionPatch.logger.info("加密文档解析异常!");
                }
                else if ("FileIsDamaged".equals(ret)) {
                    SysAttJGSaveFileFunctionPatch.logger.info("文件损坏!");
                }
                else if ("EmptyDocument".equals(ret)) {
                    SysAttJGSaveFileFunctionPatch.logger.info("空文档!保存");
                    canSave = true;
                }
                else if ("DocumentNotWord".equals(ret)) {
                    SysAttJGSaveFileFunctionPatch.logger.info("文档类型不是word类型!");
                }
                else if ("DocumentNotExcel".equals(ret)) {
                    SysAttJGSaveFileFunctionPatch.logger.info("文档类型不是excel类型!");
                }
                else if ("FileEmpty".equals(ret)) {
                    SysAttJGSaveFileFunctionPatch.logger.info("文件流为空!");
                }
                else if ("TheFileFormatIsNotSupported".equals(ret)) {
                    SysAttJGSaveFileFunctionPatch.logger.info("文件类型不支持!");
                }
                else {
                    SysAttJGSaveFileFunctionPatch.logger.info("POI检验文档因未知原因失败!");
                }
                tmpFile.delete();
            }
        }
        else if (".ppt".endsWith(fileType.toLowerCase()) || ".pptx".endsWith(fileType.toLowerCase()) || ".xls".endsWith(fileType.toLowerCase()) || ".pdf".endsWith(fileType.toLowerCase())) {
            canSave = true;
        }
        if (canSave) {
            super.execute(request, MsgObj);
            return;
        }
        throw new RuntimeException("文件不合法或损坏，保存失败");
    }
}
